@@ -5,7 +5,7 @@
 # See example in the options.py file
 
 from django.conf import settings
-from danemco.apps.socketio_server.options import UserNamespace
+from socketio_server.options import UserNamespace
 
 PORT = getattr(settings, "SOCKETIO_PORT", 7000) # replace this port with yours
 HOST = getattr(settings, "SOCKETIO_HOST", "127.0.0.1")
